@@ -19,11 +19,11 @@ class NotificationStack(Stack):
 
             # the properties below are optional
             bundle_id="bundleId",
-            certificate="certificate",
-            default_authentication_method="defaultAuthenticationMethod",
+            # certificate="certificate",
+            default_authentication_method="certificate",
             enabled=False,
-            private_key="privateKey",
-            team_id="teamId",
-            token_key="tokenKey",
-            token_key_id="tokenKeyId"
+            # private_key="privateKey",
+            # team_id="teamId",
+            # token_key="tokenKey",
+            # token_key_id="tokenKeyId"
         )
\ No newline at end of file
